#!/bin/bash

###############################################################################################
#										begin pegaswitch									  #
###############################################################################################
#Checking is pegaswitch folder exists
#if the file for update only git exists we will only update
#else we will remove the folder to do a clean clone of the repository
pushd ~/ > /dev/null 2>&1
pegaswitch_update_only=false
if [ -d "pegaswitch" ]
then
	if [ -f "pegaswitch/update_only" ]
	then
		pegaswitch_update_only=true 
	else
		echo "Trying to delete ~/pegaswitch for doing a clean git clone"
		sudo rm -r "pegaswitch"
		if [ -d "pegaswitch" ]
		then
			echo "Error: path failed to be deleted."
			echo "Exiting."
			exit 1 
		fi
	fi
fi
#Now that we know what we need to do lets do it
if [ "$pegaswitch_update_only" = true ]
then
	echo "Updating pegaswitch"
	pushd pegaswitch > /dev/null 2>&1
	git fetch --all
	git reset --hard origin/master
	touch "update_only"
	popd > /dev/null 2>&1
else
	git clone --recursive https://github.com/reswitched/pegaswitch.git
	if ! [ -d "pegaswitch" ]
	then
		echo "Error: Could not clone the pegaswitch repository."
		echo "Exiting."
		exit 1 
	fi
	touch "pegaswitch/update_only"
fi

pushd pegaswitch > /dev/null 2>&1
# Install the pegaswitch dependencies
npm i
# Create nros directory if needed
if ! [ -d "nros" ]
then
	mkdir nros
fi
popd > /dev/null 2>&1 # pegaswitch
popd > /dev/null 2>&1 # ~/
###############################################################################################
#										end pegaswitch										  #
###############################################################################################

###############################################################################################
#										begin libtransistor									  #
###############################################################################################
#Checking if pip3 exists, and if not install it.
if ! [ -x "$(command -v pip3)" ]
then
	echo "Error: python3-pip is not installed." 
	echo "Will try to install it now." 
	sudo apt-get install python3-pip
	if ! [ -x "$(command -v pip3)" ]
	then
		echo "Error: python3-pip could not be installed." 
		echo "Exiting."
		exit 1 		
	fi
fi

#Checking is libtransistor folder exists
#if the file for update only git exists we will only update
#else we will remove the folder to do a clean clone of the repository
pushd ~/ > /dev/null 2>&1
libtransistor_update_only=false
if [ -d "libtransistor" ]
then
	if [ -f "libtransistor/update_only" ]
	then
		libtransistor_update_only=true 
	else
		echo "Trying to delete ~/libtransistor for doing a clean git clone"
		sudo rm -r "libtransistor"
		if [ -d "libtransistor" ]
		then
			echo "Error: path failed to be deleted."
			echo "Exiting."
			exit 1 
		fi
	fi
fi
#Now that we know what we need to do lets do it
if [ "$libtransistor_update_only" = true ]
then
	echo "Updating libtransistor"
	pushd libtransistor > /dev/null 2>&1
	git fetch --all
	git reset --hard origin/fs
	touch "update_only"
	popd > /dev/null 2>&1
else
	git clone --recursive -b fs https://github.com/reswitched/libtransistor.git
	if ! [ -d "libtransistor" ]
	then
		echo "Error: Could not clone the libtransistor repository."
		echo "Exiting."
		exit 1 
	fi
	touch "libtransistor/update_only"
fi

pushd libtransistor > /dev/null 2>&1
# Install the python dependencies. On ArchLinux
pip install -r requirements.txt
# On everything else
pip3 install -r requirements.txt
# Compile libtransistor
echo "Compiling libtransistor"
make LLVM_POSTFIX=-5.0
# Compile ace_loader
pushd projects/ace_loader > /dev/null 2>&1
echo "Compiling ace_loader"
make LLVM_POSTFIX=-5.0
cp ace.nro ../../../pegaswitch/nros/ace.nro
popd > /dev/null 2>&1 # projects/ace_loader
popd > /dev/null 2>&1 # libtransistor
popd > /dev/null 2>&1 # ~/
###############################################################################################
#										end libtransistor									  #
###############################################################################################

###############################################################################################
#										begin libretro-fceumm								  #
###############################################################################################
#Checking is libretro-fceumm folder exists
#if the file for update only git exists we will only update
#else we will remove the folder to do a clean clone of the repository
pushd ~/ > /dev/null 2>&1
libretro_fceumm_update_only=false
if [ -d "libretro-fceumm" ]
then
	if [ -f "libretro-fceumm/update_only" ]
	then
		libretro_fceumm_update_only=true 
	else
		echo "Trying to delete ~/libretro-fceumm for doing a clean git clone"
		sudo rm -r "libretro-fceumm"
		if [ -d "libretro-fceumm" ]
		then
			echo "Error: path failed to be deleted."
			echo "Exiting."
			exit 1 
		fi
	fi
fi
#Now that we know what we need to do lets do it
if [ "$libretro_fceumm_update_only" = true ]
then
	echo "Updating libretro-fceumm"
	pushd libretro-fceumm > /dev/null 2>&1
	git fetch --all
	git reset --hard origin/master
	touch "update_only"
	popd > /dev/null 2>&1
else
	git clone --recursive https://github.com/libretro/libretro-fceumm.git
	if ! [ -d "libretro-fceumm" ]
	then
		echo "Error: Could not clone the libretro-fceumm repository."
		echo "Exiting."
		exit 1 
	fi
	touch "libretro-fceumm/update_only"
fi

pushd libretro-fceumm > /dev/null 2>&1
echo "Compiling libretro-fceumm"
make LLVM_POSTFIX=-5.0 platform=switch LIBTRANSISTOR_HOME=/home/$USER/libtransistor/
popd > /dev/null 2>&1 # libretro-fceumm
popd > /dev/null 2>&1 # ~/
###############################################################################################
#										end libretro-fceumm					 				  #
###############################################################################################

###############################################################################################
#										begin libtransistor-snes9x2010						  #
###############################################################################################
#Checking is libtransistor-snes9x2010 folder exists
#if the file for update only git exists we will only update
#else we will remove the folder to do a clean clone of the repository
pushd ~/ > /dev/null 2>&1
libtransistor_snes9x2010_update_only=false
if [ -d "libtransistor-snes9x2010" ]
then
	if [ -f "libtransistor-snes9x2010/update_only" ]
	then
		libtransistor_snes9x2010_update_only=true 
	else
		echo "Trying to delete ~/libtransistor-snes9x2010 for doing a clean git clone"
		sudo rm -r "libtransistor-snes9x2010"
		if [ -d "libtransistor-snes9x2010" ]
		then
			echo "Error: path failed to be deleted."
			echo "Exiting."
			exit 1 
		fi
	fi
fi
#Now that we know what we need to do lets do it
if [ "$libtransistor_snes9x2010_update_only" = true ]
then
	echo "Updating libtransistor-snes9x2010"
	pushd libtransistor-snes9x2010 > /dev/null 2>&1
	git fetch --all
	git reset --hard origin/master
	touch "update_only"
	popd > /dev/null 2>&1
else
	git clone --recursive https://github.com/reswitched/libtransistor-snes9x2010.git
	if ! [ -d "libtransistor-snes9x2010" ]
	then
		echo "Error: Could not clone the libtransistor-snes9x2010 repository."
		echo "Exiting."
		exit 1 
	fi
	touch "libtransistor-snes9x2010/update_only"
fi

pushd libtransistor-snes9x2010 > /dev/null 2>&1
echo "Compiling libtransistor-snes9x2010"
make LLVM_POSTFIX=-5.0 platform=switch LIBTRANSISTOR_HOME=/home/$USER/libtransistor/
popd > /dev/null 2>&1 # libtransistor-snes9x2010
popd > /dev/null 2>&1 # ~/
###############################################################################################
#										end libtransistor-snes9x2010		 				  #
###############################################################################################

###############################################################################################
#										begin vba-next										  #
###############################################################################################
#Checking is vba-next folder exists
#if the file for update only git exists we will only update
#else we will remove the folder to do a clean clone of the repository
pushd ~/ > /dev/null 2>&1
vba_next_update_only=false
if [ -d "vba-next" ]
then
	if [ -f "vba-next/update_only" ]
	then
		vba_next_update_only=true 
	else
		echo "Trying to delete ~/vba-next for doing a clean git clone"
		sudo rm -r "vba-next"
		if [ -d "vba-next" ]
		then
			echo "Error: path failed to be deleted."
			echo "Exiting."
			exit 1 
		fi
	fi
fi
#Now that we know what we need to do lets do it
if [ "$vba_next_update_only" = true ]
then
	echo "Updating vba-next"
	pushd vba-next > /dev/null 2>&1
	git fetch --all
	git reset --hard origin/master
	touch "update_only"
	popd > /dev/null 2>&1
else
	git clone --recursive https://github.com/libretro/vba-next.git
	if ! [ -d "vba-next" ]
	then
		echo "Error: Could not clone the vba-next repository."
		echo "Exiting."
		exit 1 
	fi
	touch "vba-next/update_only"
fi

pushd vba-next > /dev/null 2>&1
echo "Compiling vba-next"
make LLVM_POSTFIX=-5.0 platform=switch LIBTRANSISTOR_HOME=/home/$USER/libtransistor/
popd > /dev/null 2>&1 # vba-next
popd > /dev/null 2>&1 # ~/
###############################################################################################
#										end vba-next						 				  #
###############################################################################################

###############################################################################################
#										begin RetroArch										  #
###############################################################################################
#Checking is RetroArch folder exists
#if the file for update only git exists we will only update
#else we will remove the folder to do a clean clone of the repository
pushd ~/ > /dev/null 2>&1
RetroArch_update_only=false
if [ -d "RetroArch" ]
then
	if [ -f "RetroArch/update_only" ]
	then
		RetroArch_update_only=true 
	else
		echo "Trying to delete ~/RetroArch for doing a clean git clone"
		sudo rm -r "RetroArch"
		if [ -d "RetroArch" ]
		then
			echo "Error: path failed to be deleted."
			echo "Exiting."
			exit 1 
		fi
	fi
fi
#Now that we know what we need to do lets do it
if [ "$RetroArch_update_only" = true ]
then
	echo "Updating RetroArch"
	pushd RetroArch > /dev/null 2>&1
	git fetch --all
	git reset --hard origin/master
	touch "update_only"
	popd > /dev/null 2>&1
else
	git clone --recursive https://github.com/reswitched/RetroArch.git
	if ! [ -d "RetroArch" ]
	then
		echo "Error: Could not clone the RetroArch repository."
		echo "Exiting."
		exit 1 
	fi
	touch "RetroArch/update_only"
fi

pushd RetroArch > /dev/null 2>&1
# Create fs directory if needed
if ! [ -d "fs" ]
then
	mkdir fs
fi
popd > /dev/null 2>&1 # RetroArch
popd > /dev/null 2>&1 # ~/
###############################################################################################
#										end RetroArch						 				  #
###############################################################################################

echo "Done. Copy your roms to RetroArch/fs and run the buildretro script"